@@ -1,8 +1,7 @@
 from bdantic.parse import (  # noqa: F401
     parse,
     parse_all,
-    parse_entries,
+    parse_directives,
     parse_loader,
     parse_query,
-    parse_realize,
 )
